#include "particle.h"
#include "ofMain.h"


//------------------------------------------------------------
particle::particle(){
	setInitialCondition(0,0,0,0);
	damping = 0.01f;
}

//------------------------------------------------------------
void particle::resetForce(){
    // we reset the forces every frame
    frc.set(0,0);
}

//------------------------------------------------------------
void particle::addForce(float x, float y){
    // add in a force in X and Y for this frame.
    frc.x = frc.x + x;
    frc.y = frc.y + y;
}

//------------------------------------------------------------
void particle::addDampingForce(){
	
	// the usual way to write this is  vel *= 0.99
	// basically, subtract some part of the velocity 
	// damping is a force operating in the oposite direction of the 
	// velocity vector
	
    frc.x = frc.x - vel.x * damping;
    frc.y = frc.y - vel.y * damping;
}

//------------------------------------------------------------
void particle::setInitialCondition(float px, float py, float vx, float vy){
    pos.set(px,py);
	vel.set(vx,vy);
	points.clear();
}

//------------------------------------------------------------
void particle::update(){	
	vel = vel + frc;
	pos = pos + vel;
	
	ofPoint temp;
	temp.x = pos.x;
	temp.y = pos.y;
	points.push_back(temp);
	if (points.size() > 20){
		points.erase(points.begin());
	}
}

//------------------------------------------------------------
void particle::draw(){
    ofSetColor(255, 0, 127);
	ofFill();
	ofCircle(pos.x, pos.y, 3);
	
	ofNoFill();
	ofBeginShape();
	for (int i = 0; i < points.size(); i++){
	ofVertex(points[i].x, points[i].y);
	}
ofEndShape();

	
}
